@@ -15,6 +15,7 @@
 #include <gtk/gtkobject.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtkmenu.h>
 
 typedef struct _BonoboControl BonoboControl;
 
@@ -45,7 +46,11 @@ typedef struct {
 
 	POA_Bonobo_Control__epv epv;
 
+	gpointer dummy[2];
+
 	/* Signals. */
+	void (*plug_created)   (BonoboControl *control);
+	void (*disconnected)   (BonoboControl *control);
 	void (*set_frame)      (BonoboControl *control);
 	void (*activate)       (BonoboControl *control, gboolean state);
 } BonoboControlClass;
@@ -77,6 +82,7 @@ void                        bonobo_control_unset_transient_for     (BonoboContro
 GType                       bonobo_control_get_type                (void) G_GNUC_CONST;
 BonoboControl              *bonobo_control_construct               (BonoboControl       *control,
 								    GtkWidget           *widget);
+BonoboPlug                 *bonobo_control_get_plug                (BonoboControl       *control);
 BonoboUIComponent          *bonobo_control_get_ui_component        (BonoboControl       *control);
 void                        bonobo_control_set_ui_component        (BonoboControl       *control,
 								    BonoboUIComponent   *component);
@@ -113,6 +119,28 @@ void                        bonobo_control_set_popup_ui_container  (BonoboContro
 gboolean                    bonobo_control_do_popup                (BonoboControl       *control,
 								    guint                button,
 								    guint32              activate_time);
+gboolean                    bonobo_control_do_popup_full           (BonoboControl       *control,
+								    GtkWidget           *parent_menu_shell,
+								    GtkWidget           *parent_menu_item,
+								    GtkMenuPositionFunc  func,
+								    gpointer             data,
+								    guint                button,
+								    guint32              activate_time);
+gboolean                    bonobo_control_do_popup_path           (BonoboControl       *control,
+								    GtkWidget           *parent_menu_shell,
+								    GtkWidget           *parent_menu_item,
+								    GtkMenuPositionFunc  func,
+								    gpointer             data,
+								    guint                button,
+								    const char          *popup_path,
+								    guint32              activate_time);
+
+/* Simple lifecycle helpers - using the 'disconnected' signal */
+typedef void (*BonoboControlLifeCallback) (void);
+void bonobo_control_life_set_purge    (long                      ms);
+void bonobo_control_life_set_callback (BonoboControlLifeCallback all_dead_callback);
+void bonobo_control_life_instrument   (BonoboControl            *control);
+int  bonobo_control_life_get_count    (void);
 
 G_END_DECLS
 
